@@ -1,6 +1,6 @@
 #include <config.h>
 
-/* PostgreSQL backend, by Cindy Marasco <cindy@getaclue.org> */
+/* PostgreSQL backend, by Cindy Marasco <cindy at getaclue.org> */
 
 #ifdef WITH_PGSQL
 
@@ -403,7 +403,7 @@ void pw_pgsql_check(AuthResult * const result,
     char *escaped_decimal_ip = NULL;    
     char *scrambled_password = NULL;
     int committed = 1;
-    int crypto_crypt = 0, crypto_plain = 0, crypto_md5 = 0;
+    int crypto_crypt = 0, crypto_md5 = 0, crypto_sha1 = 0, crypto_plain = 0;
     unsigned long decimal_ip_num = 0UL;
     char decimal_ip[42];
     char hbuf[NI_MAXHOST];
@@ -494,10 +494,13 @@ void pw_pgsql_check(AuthResult * const result,
     if (strcasecmp(crypto, PASSWD_SQL_ANY) == 0) {
         crypto_crypt++;
         crypto_md5++;
+        crypto_sha1++;        
     } else if (strcasecmp(crypto, PASSWD_SQL_CRYPT) == 0) {
         crypto_crypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MD5) == 0) {
         crypto_md5++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_SHA1) == 0) {
+        crypto_sha1++;
     } else {                           /* default to plaintext */
         crypto_plain++;
     }
@@ -517,6 +520,14 @@ void pw_pgsql_check(AuthResult * const result,
             goto auth_ok;
         }
     }
+    if (crypto_sha1 != 0) {
+        const char *crypted;
+        
+        if ((crypted = (const char *) crypto_hash_sha1(password, 1)) != NULL &&
+            strcmp(crypted, spwd) == 0) {
+            goto auth_ok;
+        }
+    }
     if (crypto_plain != 0) {
         if (*password != 0 &&    /* refuse null cleartext passwords */
             strcmp(password, spwd) == 0) {
